@@ -6,7 +6,7 @@ use warnings;
 use DynaLoader ();
 
 use vars qw( $VERSION @ISA @EXPORT @EXPORT_OK );
-$VERSION   = "0.35";
+$VERSION   = "0.37";
 @ISA       = qw( DynaLoader Exporter );
 @EXPORT    = qw( DDumper DTidy DDsort DPeek DDisplay DDump DHexDump
 		 DDual DGrow );
@@ -203,7 +203,8 @@ sub DHexDump
     my @out;
     my $var = @_ ? $_[0] : $_;
     defined $var or return;
-    my $str = "$var";	# force stringification
+    my $fmt = @_ > 1 && $_[1] < length ($var) ? "A$_[1]" : "A*";
+    my $str = pack $fmt, $var;	# force stringification
     for (unpack "(A32)*", unpack "H*", $str) {
 	my @b = unpack "(A2)*", $_;
 	my $out = sprintf "%04x ", $off;
@@ -389,9 +390,12 @@ Example
 
 =head2 DHexDump ($var)
 
+=head2 DHexDump ($var, $length)
+
 Show the (stringified) content of a scalar as a hex-dump.  If C<$var>
 is omitted, C<$_> is dumped. Returns C<undef> or an empty list if
-C<$var> (or C<$_>) is undefined.
+C<$var> (or C<$_>) is undefined. If C<$length> is given and is lower than
+the length of the stringified C<$var>, only <$length> bytes are dumped.
 
 In void context, the dump is done to STDERR. In scalar context, the
 complete dump is returned as a single string. In list context, the dump
@@ -441,11 +445,10 @@ not shrink.
      grow => q{my $x = ""; DGrow ($x,  20000); $x = "";},
      });
 
-           Rate  op_x  pack  grow
- op_x   62127/s    --  -59%  -96%
- pack  152046/s  145%    --  -91%
- grow 1622943/s 2512%  967%    --
-
+           Rate  op_x  pack  grow      5.8.9    5.10.1    5.12.4    5.14.2
+ op_x   62127/s    --  -59%  -96%   118606/s  119730/s  352255/s  362605/s
+ pack  152046/s  145%    --  -91%   380075/s  355666/s  347247/s  387349/s
+ grow 1622943/s 2512%  967%    --  2818380/s 2918783/s 2672340/s 2886787/s
 
 =head2 my $tp = triplevar ($pv, $iv, $nv)
 
@@ -674,7 +677,7 @@ H.Merijn Brand <h.m.brand@xs4all.nl>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2011 H.Merijn Brand
+Copyright (C) 2008-2012 H.Merijn Brand
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
